<template>
    当前患者: {{patient?.patId}} {{isStringEmpty(patient?.patName)?'无':patient.patName}}
    <Qrcode :text="patient?.patId" logo="/logo.gif" width=100 />
    <el-form
      ref="formRef"
      :model="formData"
      :rules="formRules"
      label-width="100px"
      v-loading="formLoading"
    >
      <el-form-item label="患者描述" prop="patDeptDesc">
        科室: {{formData.patDeptDesc}} 病区: {{formData.patWardDesc}} 床位: {{formData.patBedNo}}
      </el-form-item>
      <el-form-item label="设备编号" prop="devId">
        <el-input v-model="formData.devId" placeholder="请输入设备编号" @input="getDevInfo"/>
      </el-form-item>
      <el-form-item label="设备描述" prop="">
        {{deviceInfo.brand + "&nbsp;&nbsp;" + deviceInfo.model + " " + deviceInfo.state}}
      </el-form-item>
      <el-form-item label="装机时间" prop="rentTime">
        <el-date-picker
          v-model="formData.rentTime"
          type="date"
          value-format="x"
          placeholder="选择装机时间"
        />
      </el-form-item>
      <el-form-item label="备注" prop="remark">
        <el-input v-model="formData.remark" placeholder="请输入备注" />
      </el-form-item>
      <el-form-item label="缴费确认" prop="paid">
        <el-radio-group v-model="formData.paid">
          <el-radio key="1" :label="1"> 已缴费 </el-radio>
          <el-radio key="0" :label="0"> 未缴费 </el-radio>
        </el-radio-group>
      </el-form-item>
    </el-form>
    <el-button @click="submitForm" type="primary" :disabled="formLoading">领用完成</el-button>
    <el-button @click="resetForm()">重 置</el-button>
    <el-button @click="printBill()">打印小票</el-button>
    <el-button @click="cancelInstall"  :disabled="formLoading">放弃装机</el-button>

  <!-- 医生装机列表 -->
  <ContentWrap>
    <el-table v-loading="loading" :data="list" :stripe="true" :show-overflow-tooltip="true" @row-click="onRowClick" >
      <el-table-column label="id" align="center" prop="id" />
      <el-table-column label="缴费" align="center" prop="paid">
        <template #default="scope">
          {{scope.row.paid == 1 ? "已缴" : ""}}
        </template>
      </el-table-column>
      <el-table-column label="领用情况" align="center" prop="cancelled" >
        <template #default="scope">
          <span v-if="scope.row.jobType === 5">"已领用"</span>
          <span v-if="scope.row.jobType === 30">"已放弃"</span>
        </template>
      </el-table-column>
<!--      <el-table-column label="作业类型" align="center" prop="jobType" />-->
<!--      <el-table-column label="医生编号" align="center" prop="docId" />-->
      <el-table-column label="医生名称" align="center" width="auto" prop="docName" />
      <el-table-column label="设备编号" align="center" prop="devId" />
<!--      <el-table-column label="患者编号" align="center" prop="patId" />-->
      <el-table-column label="患者名称" align="center" prop="patName" />
      <el-table-column
          label="作业时间"
          align="center"
          prop="jobTime"
          :formatter="dateFormatter"
          width="180px"
      />
<!--      <el-table-column label="作业概要" align="center" prop="summary" />-->
      <el-table-column label="备注" align="center" prop="remark" />
<!--
      <el-table-column
          label="创建时间"
          align="center"
          prop="createTime"
          :formatter="dateFormatter"
      />
-->
<!--
      <el-table-column label="操作" align="center" min-width="120px">
        <template #default="scope">
          <el-button
              link
              type="primary"
              @click="openForm('update', scope.row.id)"
              v-hasPermi="['ecg:job-record:update']"
          >
            编辑
          </el-button>
          <el-button
              link
              type="danger"
              @click="handleDelete(scope.row.id)"
              v-hasPermi="['ecg:job-record:delete']"
          >
            删除
          </el-button>
        </template>
      </el-table-column>
-->
    </el-table>
    <!-- 分页 -->
    <Pagination
        :total="total"
        v-model:page="queryParams.pageNo"
        v-model:limit="queryParams.pageSize"
        @pagination="getList"
    />
  </ContentWrap>

</template>

<script setup lang="ts">
import {defineComponent, PropType} from "vue";
import { DevRentApi, DevRentVO } from '@/api/ecg/devrent'
import {QueueVO} from "@/api/ecg/queue";
import {isStringEmpty} from "@/utils/stringUtil";
import {dateFormatter, timeFormatter} from "@/utils/formatTime";
import {JobRecordApi, JobRecordVO} from "@/api/ecg/jobrecord";
import {DeviceApi, DeviceVO} from "@/api/ecg/devmanage";
import {curDayEnd, curDayStart} from "@/utils/dateUtil";

/** 装机拆机 表单 */
defineComponent({ name: 'DevReadyPanel' })

const emit = defineEmits(['success-ready']) // 定义 success 事件，用于操作成功后的回调

const { t } = useI18n() // 国际化
const message = useMessage() // 消息弹窗

const dialogVisible = ref(false) // 弹窗的是否展示

const formLoading = ref(false) // 表单的加载中：1）修改时的数据加载；2）提交的按钮禁用
const formType = ref('create') // 表单的类型：create - 新增；update - 修改

const patient = ref<QueueVO>({
  patId: '',
  patName: ''
})

const formData = ref({
  id: undefined,
  devId: undefined,
  patId: patient.value?.patId,
  patName: patient.value?.patName,
  patDeptCode: undefined,
  patDeptDesc: undefined,
  patWardCode: undefined,
  patWardDesc: undefined,
  patBedNo: undefined,
  rentTime: new Date().getTime(),
  returnTime: undefined,
  interference: undefined,
  baseline: undefined,
  detachment: undefined,
  remark: undefined,
  paid: undefined
})
const formRules = reactive({
  devId: [{ required: true, message: '设备编号不能为空', trigger: 'blur' }],
  rentTime: [{ required: true, message: '请选择装机日期', trigger: 'blur' }],
  patId: [{ required: true, message: '目前没有患者', trigger: 'blur' }],
  patName: [{ required: true, message: '目前没有患者', trigger: 'blur' }]
})
const formRef = ref() // 表单 Ref

const deviceInfo = ref<DeviceVO> ({
  id: 0,
  devId: '',
  category: '',
  brand: '',
  model: '',
  purchaseDate: 0,
  state: 0,
})

/** 提交表单 */
const submitForm = async () => {
  // 校验表单
  await formRef.value.validate()
  // 提交请求
  formLoading.value = true
  try {
    const data = formData.value as unknown as DevRentVO
    if (formData.value.id === null || formData.value.id === undefined) {
      const result = await DevRentApi.devReady(data)
      formData.value.id = result
      message.success(t('操作完成'))
    } else {
      await DevRentApi.devReady(data)
      message.success(t('更新完成'))
    }
    dialogVisible.value = false
    // 发送操作成功的事件
    emit('success-ready')
    resetForm()
    getList()
  } finally {
    formLoading.value = false
  }
}

const cancelInstall = async () => {
  const data = formData.value as unknown as DevRentVO
  if (formData.value.id === null || formData.value.id === undefined) {
    const result = await DevRentApi.devReadyCancel(data)
    formData.value.id = result
    message.success(t('操作成功'))
  } else {
    await DevRentApi.devReadyCancel(data)
    message.success(t('操作成功'))
  }
  // 发送操作成功的事件
  emit('success-ready')
  resetForm()
  getList()
}

/** 重置表单 */
const resetForm = () => {
  formData.value = {
    id: undefined,
    devId: undefined,
    patId: patient.value?.patId,
    patName: patient.value?.patName,
    rentTime: new Date().getTime(),
    returnTime: undefined,
    interference: undefined,
    baseline: undefined,
    detachment: undefined,
    remark: undefined
  }
  formRef.value?.resetFields()

  deviceInfo.value.category = ''
  deviceInfo.value.brand = ''
  deviceInfo.value.model = ''
  deviceInfo.value.state = 0
}

const setPatient = (queueVO: QueueVO | undefined) => {
  patient.value = queueVO
  resetForm()
}
defineExpose({ setPatient }) // 提供 setPatient 方法，用于设置患者


const loading = ref(true) // 列表的加载中
const list = ref<JobRecordVO[]>([]) // 列表的数据
const total = ref(0) // 列表的总页数
const queryParams = reactive({
  pageNo: 1,
  pageSize: 10,
  jobType: [5, 30],
  docId: undefined,
  docName: undefined,
  devId: undefined,
  patId: undefined,
  patName: undefined,
  jobTime: [curDayStart(), curDayEnd()],
  summary: undefined,
  remark: undefined,
  createTime: []
})

/** 查询列表 */
const getList = async () => {
  loading.value = true
  try {
    const data = await JobRecordApi.getJobRecordDoctorPage(queryParams)
    list.value = data.list
    total.value = data.total
  } finally {
    loading.value = false
  }
}

const onRowClick = (cur) => {
  if (cur !== null)
    getSelectedRent( cur.rentId )
}

const getSelectedRent = async (rentId) => {
  formData.value = await DevRentApi.getDevRent(rentId)
}

const printBill = async () => {
  ElNotification({
    title: '温馨提示',
    message: '待实现！',
    type: 'warning'
  })
}

const getDevInfo = async () => {
  deviceInfo.value.category = ''
  deviceInfo.value.brand = ''
  deviceInfo.value.model = ''
  deviceInfo.value.state = 0
  if (isStringEmpty(formData.value.devId))
    return

  const data = await DeviceApi.getDeviceByDevId(formData.value.devId!)
  console.info( data )
  if ( null !== data)
    deviceInfo.value = data
}

/** 初始化 **/
onMounted(() => {
  getList()
})

</script>

